TableView
==================================

.. currentmodule:: enaml.widgets.table_view

.. autoclass:: TableView


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_table_view.QtTableView
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_table_view.QtTableView

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_table_view.WXTableView
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_table_view.WXTableView
